==> apache-ambari-2.7.7-src.tar.gz: apache-ambari-2.7.7-src/ambari-server/src/main/java/org/apache/ambari/server/utils/JsonUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ambari.server.utils;

import org.apache.commons.lang.StringUtils;

import com.google.gson.JsonParser;
import com.google.gson.JsonSyntaxException;

/**
 * Static Helper methods for Json processing.
 */
public class JsonUtils {

  public static JsonParser jsonParser = new JsonParser();

  /**
   * Checks if an input string is in valid JSON format
   * @param jsonString input json string to validate
   * @return <tt>true</tt> if the input string is in valid JSON format
   */
  public static boolean isValidJson(String jsonString) {

    if(StringUtils.isBlank(jsonString)) {
      return false;
    }
    try {
      jsonParser.parse(jsonString);
      return true;
    } catch (JsonSyntaxException jse) {
      return false;
    }
  }
}

==> apache-ambari-3.0.0-src.tar.gz: apache-ambari-3.0.0-src/ambari-server/src/main/java/org/apache/ambari/server/utils/JsonUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.ambari.server.utils;

import org.apache.commons.lang.StringUtils;

import com.google.gson.JsonParser;
import com.google.gson.JsonSyntaxException;

/**
 * Static Helper methods for Json processing.
 */
public class JsonUtils {

  public static final JsonParser jsonParser = new JsonParser();

  /**
   * Checks if an input string is in valid JSON format
   * @param jsonString input json string to validate
   * @return <tt>true</tt> if the input string is in valid JSON format
   */
  public static boolean isValidJson(String jsonString) {

    if(StringUtils.isBlank(jsonString)) {
      return false;
    }
    try {
      jsonParser.parse(jsonString);
      return true;
    } catch (JsonSyntaxException jse) {
      return false;
    }
  }
}
